@@ -5,9 +5,10 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: _base.py 3689 2006-07-24 07:31:20Z piman $
+# $Id: _base.py 3845 2006-09-17 05:51:21Z piman $
 
 import gobject
+import gtk
 
 from qltk.songsmenu import SongsMenu
 
@@ -32,10 +33,31 @@ class Browser(object):
     in_menu = True
 
     # Packing options. False if the browser should be packed into the
-    # window's VBox with expand=False. Otherwise, this should be
-    # a function that returns an object like an RPaned; the browser
-    # and MainSongList are both packed into it.
-    expand = False # Packing options
+    # window's VBox with expand=False. A subclass of Paned to automatically
+    # pack the browser into the first and the MainSongList into the second
+    # pane. If you override the pack() method this will not be called.
+    expand = None
+
+    # For custom packing, define a function that returns a Widget with the
+    # browser and MainSongList both packed into it. If you need
+    # a custom pack() method, you probably also need a custom unpack()
+    # method.
+    def pack(self, songpane):
+        if self.expand is not None:
+            container = self.expand()
+            container.pack1(self, resize=True)
+            container.pack2(songpane, resize=True)
+        else:
+            container = gtk.VBox(spacing=6)
+            container.pack_start(self, expand=False)
+            container.pack_start(songpane)
+        return container
+
+    # Unpack the browser and songlist when switching browsers in the main
+    # window. The container will be automatically destroyed afterwards.
+    def unpack(self, container, songpane):
+        container.remove(songpane)
+        container.remove(self)
 
     # If true, the global filter will be applied by MainSongList to
     # the songs returned.
