@@ -5,42 +5,50 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: search.py 2758 2006-01-25 19:36:18Z piman $
+# $Id: search.py 3634 2006-07-14 19:38:41Z piman $
 
 import os
 import random
-import gobject, gtk
-import const
+
+import gtk
+
 import config
-
+import const
 import qltk
-from qltk.completion import LibraryTagCompletion
-from qltk.cbes import ComboBoxEntrySave
-from qltk.songlist import SongList
-from qltk import Tooltips
-from browsers._base import Browser
-from library import library
-from parse import Query
 
-QUERIES = os.path.join(const.DIR, "lists", "queries")
+from browsers._base import Browser
+from parse import Query
+from qltk.cbes import ComboBoxEntrySave
+from qltk.completion import LibraryTagCompletion
+from qltk.songlist import SongList
+from qltk.x import Tooltips
+
+QUERIES = os.path.join(const.USERDIR, "lists", "queries")
 
 # A browser that the user only interacts with indirectly, via the
 # Filter menu. The HBox remains empty.
 class EmptyBar(gtk.HBox, Browser):
     __gsignals__ = Browser.__gsignals__
 
-    def __init__(self, watcher, player):
-        gtk.HBox.__init__(self)
+    name = _("Disable Browser")
+    accelerated_name = _("_Disable Browser")
+    priority = 0
+    in_menu = False
+
+    def __init__(self, library, player):
+        super(EmptyBar, self).__init__()
         # When _text is None, calls to activate are ignored. This is to
         # avoid the song list changing when the user switches browses and
         # then refreshes.
         self._text = None
+        self._filter = None
+        self._library = library
         self.__main = bool(player)
+        self.commands = {"query": self.__query}
 
     def dynamic(self, song):
-        if self._text is not None:
-            try: return Query(self._text, SongList.star).search(song)
-            except Query.error: return True
+        if self._filter is not None:
+            return self._filter(song)
         else: return True
 
     def set_text(self, text):
@@ -49,6 +57,10 @@ class EmptyBar(gtk.HBox, Browser):
 
     status = property(lambda s: s._text)
 
+    def __query(self, text, library, window, player):
+        self.set_text(text)
+        self.activate()
+
     def save(self):
         config.set("browsers", "query_text", self._text.encode('utf-8'))
 
@@ -58,9 +70,10 @@ class EmptyBar(gtk.HBox, Browser):
 
     def activate(self):
         if self._text is not None:
-            try: songs = library.query(self._text, star=SongList.star)
+            try: self._filter = Query(self._text, star=SongList.star).search
             except Query.error: pass
             else:
+                songs = filter(self._filter, self._library)
                 self.emit('songs-selected', songs, None)
                 if self.__main: self.save()
 
@@ -81,8 +94,6 @@ class EmptyBar(gtk.HBox, Browser):
             else: self.set_text(u"%s = |(%s)" % (key, text))
         self.activate()
 
-gobject.type_register(EmptyBar)
-
 class Limit(gtk.HBox):
     def __init__(self):
         super(Limit, self).__init__(spacing=3)
@@ -105,12 +116,12 @@ class Limit(gtk.HBox):
         if not limit or len(songs) < limit: return songs
         else:
             if self.__weight.get_active():
-                songs = [(song.get("~#rating", 0.5), song) for song in songs]
-                def choose((r1, s1), (r2, s2)):
+                def choose(r1, r2):
                     if r1 or r2: return cmp(random.random(), r1/(r1+r2))
                     else: return random.randint(-1, 1)
-                songs.sort(choose)
-                songs = [song for (rating, song) in songs]
+                def rating(song):
+                    return song.get("~#rating", 0.5)
+                songs.sort(cmp=choose, key=rating)
             else: random.shuffle(songs)
             return songs[:limit]
         
@@ -118,8 +129,14 @@ class Limit(gtk.HBox):
 # is QL's default browser. EmptyBar handles all the GObject stuff.
 class SearchBar(EmptyBar):
 
-    def __init__(self, watcher, player):
-        EmptyBar.__init__(self, watcher, player)
+    name = _("Search Library")
+    accelerated_name = _("_Search Library")
+    priority = 1
+    in_menu = True
+
+    def __init__(self, library, player):
+        super(SearchBar, self).__init__(library, player)
+
         self.__save = bool(player)
         self.set_spacing(12)
 
@@ -130,15 +147,11 @@ class SearchBar(EmptyBar):
         l = gtk.Label(_("_Search:"))
         l.connect('mnemonic-activate', self.__mnemonic_activate)
         tips = Tooltips(self)
-        combo = ComboBoxEntrySave(
-            QUERIES, model="searchbar", count=15)
-        combo.child.set_completion(LibraryTagCompletion(watcher, library))
+        combo = ComboBoxEntrySave(QUERIES, model="searchbar", count=8)
+        combo.child.set_completion(LibraryTagCompletion(library.librarian))
         l.set_mnemonic_widget(combo.child)
         l.set_use_underline(True)
-        clear = gtk.Button()
-        clear.add(gtk.image_new_from_stock(gtk.STOCK_CLEAR,gtk.ICON_SIZE_MENU))
-        tips.set_tip(clear, _("Clear search"))
-        clear.connect_object('clicked', self.set_text, "")
+        clear = qltk.ClearButton(self, tips)
 
         search = gtk.Button()
         hb = gtk.HBox(spacing=3)
@@ -186,9 +199,10 @@ class SearchBar(EmptyBar):
 
     def activate(self):
         if self._text is not None:
-            try: songs = library.query(self._text, star=SongList.star)
+            try: self._filter = Query(self._text, star=SongList.star).search
             except Query.error: pass
             else:
+                songs = filter(self._filter, self._library.itervalues())
                 self.__combo.prepend_text(self._text)
                 if self.__limit.get_property('visible'):
                     songs = self.__limit.limit(songs)
@@ -216,7 +230,4 @@ class SearchBar(EmptyBar):
         if color and textbox.get_property('sensitive'):
             textbox.modify_text(gtk.STATE_NORMAL, gtk.gdk.color_parse(color))
 
-browsers = [
-    (0, _("_Disable Browser"), EmptyBar, False),
-    (1, _("_Search Library"), SearchBar, True)
-    ]
+browsers = [EmptyBar, SearchBar]
