@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: completion.py 3807 2006-08-28 05:39:03Z piman $
+# $Id: completion.py 3814 2006-09-03 08:35:57Z piman $
 
 import gobject
 import gtk
@@ -90,7 +90,9 @@ class LibraryTagCompletion(EntryWordCompletion):
         tags = set()
         model.clear()
         yield True
-        for count, song in enumerate(library):
+        # Iterate over a new list since this function and the
+        # library updater are copooled with different IDs.
+        for count, song in enumerate(list(library)):
             for tag in song.keys():
                 if not (tag.startswith("~#") or tag in formats.MACHINE_TAGS):
                     tags.add(tag)
