@@ -4,9 +4,10 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: entry.py 2435 2005-12-07 08:39:08Z piman $
+# $Id: entry.py 3197 2006-04-26 23:00:00Z piman $
 
 import gtk
+
 import config
 
 class ValidatingEntry(gtk.Entry):
@@ -20,7 +21,7 @@ class ValidatingEntry(gtk.Entry):
     change color."""
 
     def __init__(self, validator=None, *args):
-        gtk.Entry.__init__(self, *args)
+        super(ValidatingEntry, self).__init__(*args)
         if validator: self.connect_object('changed', self.__color, validator)
 
     def __color(self, validator):
