@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: information.py 3634 2006-07-14 19:38:41Z piman $
+# $Id: information.py 3950 2006-11-19 02:01:15Z piman $
 
 import time
 
@@ -86,6 +86,9 @@ class OneSong(qltk.Notebook):
             self._people(song, vbox)
             self._library(song, vbox)
             self._file(song, vbox)
+            parent = qltk.get_top_parent(self)
+            if parent:
+                parent.set_title(self.title + " - Quod Libet")
             vbox.show_all()
 
     def _title(self, song, box):
