@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: quodlibet.py 3807 2006-08-28 05:39:03Z piman $
+# $Id: quodlibet.py 3895 2006-10-08 22:10:55Z piman $
 
 import os
 import random
@@ -43,6 +43,7 @@ from qltk.properties import SongProperties
 from qltk.prefs import PreferencesWindow
 from qltk.queue import QueueExpander
 from qltk.songlist import SongList, PlaylistMux
+from qltk.x import RPaned
 from util import copool
 from util.uri import URI
 
@@ -211,8 +212,8 @@ class QuodLibetWindow(gtk.Window):
             _("_Repeat"), "settings", "repeat")
         tips.set_tip(repeat, _("Restart the playlist when finished"))
         hbox.pack_start(repeat, expand=False)
-        self.__statusbar = StatusBar()
-        hbox.pack_start(self.__statusbar)
+        self.statusbar = StatusBar()
+        hbox.pack_start(self.statusbar)
         align.add(hbox)
         self.child.pack_end(align, expand=False)
 
@@ -506,12 +507,11 @@ class QuodLibetWindow(gtk.Window):
         Browser = browsers.get(current)
         config.set("memory", "browser", Browser.__name__)
         if self.browser:
-            c = self.__vbox.get_children()[-1]
-            c.remove(self.songpane)
-            c.remove(self.browser)
-            c.destroy()
+            container = self.browser.__container
+            self.browser.unpack(container, self.songpane)
             if self.browser.accelerators:
                 self.remove_accel_group(self.browser.accelerators)
+            container.destroy()
             self.browser.destroy()
         self.browser = Browser(library, player)
         self.browser.connect('songs-selected', self.__browser_cb)
@@ -523,31 +523,27 @@ class QuodLibetWindow(gtk.Window):
         if self.browser.accelerators:
             self.add_accel_group(self.browser.accelerators)
 
-        if self.browser.expand:
-            c = self.browser.expand()
-            c.pack1(self.browser, resize=True)
-            c.pack2(self.songpane, resize=True)
+        container = self.browser.__container = self.browser.pack(self.songpane)
+        # Save position if container is a RPaned
+        if isinstance(container, RPaned):
             try:
                 key = "%s_pos" % self.browser.__class__.__name__
                 val = config.getfloat("browsers", key)
             except: val = 0.4
-            c.connect(
+            container.connect(
                 'notify::position', self.__browser_configure, self.browser)
             def set_size(paned, alloc, pos):
                 paned.set_relative(pos)
                 paned.disconnect(paned._size_sig)
                 # The signal disconnects itself! I hate GTK sizing.
                 del(paned._size_sig)
-            sig = c.connect('size-allocate', set_size, val)
-            c._size_sig = sig
-        else:
-            c = gtk.VBox(spacing=6)
-            c.pack_start(self.browser, expand=False)
-            c.pack_start(self.songpane)
+            sig = container.connect('size-allocate', set_size, val)
+            container._size_sig = sig
+
         player.replaygain_profiles[0] = self.browser.replaygain_profiles
         player.volume = player.volume
-        self.__vbox.pack_end(c)
-        c.show()
+        self.__vbox.pack_end(container)
+        container.show()
         self.__hide_menus()
         self.__hide_headers()
         self.__refresh_size()
@@ -571,11 +567,10 @@ class QuodLibetWindow(gtk.Window):
                 self.__set_time()
 
     def __update_title(self, player, songs):
-        if player.song in songs:
-            song = player.info
-            if song:
-                self.set_title("Quod Libet - " + song.comma("~title~version"))
-            else: self.set_title("Quod Libet")
+        song = player.info
+        if song:
+            self.set_title("Quod Libet - " + song.comma("~title~version"))
+        else: self.set_title("Quod Libet")
 
     def __song_started(self, player, song):
         if song is None:
@@ -675,7 +670,7 @@ class QuodLibetWindow(gtk.Window):
 
     def __rebuild(self, activator, force):
         paths = config.get("settings", "scan").split(":")
-        copool.add(library.rebuild, paths, self.__statusbar.progress, force,
+        copool.add(library.rebuild, paths, self.statusbar.progress, force,
                    funcid="library")
 
     # Set up the preferences window.
@@ -724,7 +719,7 @@ class QuodLibetWindow(gtk.Window):
         if fns:
             if action.get_name() == "AddFolders":
                 self.last_dir = fns[0]
-                copool.add(library.scan, fns, self.__statusbar.progress,
+                copool.add(library.scan, fns, self.statusbar.progress,
                            funcid="library")
             else:
                 added = []
@@ -848,4 +843,4 @@ class QuodLibetWindow(gtk.Window):
         length = sum([song["~#length"] for song in songs])
         t = self.browser.statusbar(i) % {
             'count': i, 'time': util.format_time_long(length)}
-        self.__statusbar.count.set_text(t)
+        self.statusbar.count.set_text(t)
