@@ -5,10 +5,10 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: renamefiles.py 3696 2006-07-27 04:33:11Z mu $
+# $Id: renamefiles.py 3892 2006-10-05 11:35:13Z toupeira $
 
 import os
-import sre
+import re
 import unicodedata
 
 import gtk
@@ -35,11 +35,7 @@ class StripWindowsIncompat(FilterCheckButton):
     BAD = '\:*?;"<>|'
     _order = 1.1
     def filter(self, original, filename):
-        new = u"".join(map(lambda s: (s in self.BAD and "_") or s, filename))
-        parts = new.split(os.sep)
-        def fix_end(string):
-            return sre.sub(r'[\. ]$', "_", string)
-        return unicode(os.sep).join(map(fix_end, parts))
+        return util.strip_win32_incompat(filename)
 
 class StripDiacriticals(FilterCheckButton):
     _label = _("Strip _diacritical marks")
@@ -135,12 +131,11 @@ class RenameFiles(EditPane):
         model = self.view.get_model()
         if songs is None:
             songs = [row[0] for row in model]
-        model.clear()
         pattern = self.combo.child.get_text().decode("utf-8")
 
         try:
             pattern = FileFromPattern(pattern)
-        except ValueError: 
+        except ValueError:
             qltk.ErrorMessage(
                 self, _("Path is not absolute"),
                 _("The pattern\n\t<b>%s</b>\ncontains / but "
@@ -160,6 +155,7 @@ class RenameFiles(EditPane):
         for f in self.filters:
             if f.active: newnames = f.filter_list(orignames, newnames)
 
+        model.clear()
         for song, newname in zip(songs, newnames):
             basename = util.fsdecode(song("~basename"))
             model.append(row=[song, basename, newname])
