@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: songlist.py 3722 2006-07-30 18:15:14Z piman $
+# $Id: songlist.py 3894 2006-10-08 22:01:56Z piman $
 
 import datetime
 import random
@@ -80,7 +80,7 @@ class PlaylistMux(object):
         self.pl.reset()
         self.q.go_to(None)
         if not self.pl.is_empty():
-            self.pl.go_to(self.pl.get_iter((0,)))
+            self.next()
 
     def enqueue(self, songs):
         for song in songs: self.q.append(row=[song])
