@@ -5,10 +5,10 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: tagsfrompath.py 3634 2006-07-14 19:38:41Z piman $
+# $Id: tagsfrompath.py 3867 2006-09-23 22:32:09Z piman $
 
 import os
-import sre
+import re
 
 import gtk
 
@@ -29,7 +29,7 @@ class TagsFromPattern(object):
         self.slashes = len(pattern) - len(pattern.replace(os.path.sep,'')) + 1
         self.pattern = None
         # patterns look like <tagname> non regexy stuff <tagname> ...
-        pieces = sre.split(r'(<[A-Za-z0-9_]+>)', pattern)
+        pieces = re.split(r'(<[A-Za-z0-9_]+>)', pattern)
         override = { '<tracknumber>': r'\d\d?', '<discnumber>': r'\d\d??' }
         for i, piece in enumerate(pieces):
             if not piece: continue
@@ -38,7 +38,7 @@ class TagsFromPattern(object):
                 pieces[i] = '(?P%s%s)' % (piece, override.get(piece, '.+?'))
                 self.headers.append(piece[1:-1].encode("ascii", "replace"))
             else:
-                pieces[i] = sre.escape(piece)
+                pieces[i] = re.escape(piece)
 
         # some slight magic to anchor searches "nicely"
         # nicely means if it starts with a <tag>, anchor with a /
@@ -50,9 +50,9 @@ class TagsFromPattern(object):
             pieces.insert(0, os.path.sep)
         if pattern.endswith('>') and not pattern.endswith('<tracknumber>')\
                 and not pattern.endswith('<discnumber>'):
-            pieces.append(r'(?:\.\w+)$')
+            pieces.append(r'(?:\.[A-Za-z0-9_+]+)$')
 
-        self.pattern = sre.compile(''.join(pieces))
+        self.pattern = re.compile(''.join(pieces))
 
     def match(self, song):
         if isinstance(song, dict):
@@ -125,7 +125,7 @@ class TagsFromPath(EditPane):
         if songs: pattern_text = self.combo.child.get_text().decode("utf-8")
         else: pattern_text = ""
         try: pattern = TagsFromPattern(pattern_text)
-        except sre.error:
+        except re.error:
             qltk.ErrorMessage(
                 self, _("Invalid pattern"),
                 _("The pattern\n\t<b>%s</b>\nis invalid. "
@@ -182,7 +182,8 @@ class TagsFromPath(EditPane):
                 text = match.get(h, '')
                 for f in self.filters:
                     if f.active: text = f.filter(h, text)
-                if not song.multiple_values: text = u", ".join(text)
+                if not song.multiple_values:
+                    text = u", ".join(text.split("\n"))
                 row.append(text)
             model.append(row=row)
 
