@@ -8,7 +8,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 #
-# $Id: quodlibet.py 3716 2006-07-29 23:26:33Z piman $
+# $Id: quodlibet.py 3835 2006-09-10 21:08:27Z piman $
 
 import os
 import signal
@@ -48,7 +48,7 @@ def main():
         gtk.quit_add(1, widgets.save_library, window, player, library)
     for sig in SIGNALS:
         signal.signal(sig, gtk.main_quit)
-    gtk.threads_init()
+    gtk.gdk.threads_init()
     if play: player.paused = False
     gtk.main()
 
