@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: stock.py 3529 2006-06-30 22:26:38Z piman $
+# $Id: stock.py 3897 2006-10-08 23:34:00Z piman $
 
 import os
 
@@ -21,13 +21,21 @@ PREVIEW = 'ql-preview'
 REMOVE = 'ql-remove'
 ENQUEUE = 'ql-enqueue'
 PLAYLISTS = 'ql-add-to-playlist'
+DEVICES = 'ql-copy-to-device'
+RENAME = 'ql-rename'
 
-VOLUME_OFF = 'rhythmbox-volume-zero'
-VOLUME_MIN = 'rhythmbox-volume-min'
-VOLUME_MED = 'rhythmbox-volume-medium'
-VOLUME_MAX = 'rhythmbox-volume-max'
+IPOD = 'device-ipod'
+STORAGE = 'device-generic'
 
-_ICONS = [QL_ICON, EF_ICON, VOLUME_OFF, VOLUME_MIN, VOLUME_MED, VOLUME_MAX]
+EJECT = 'media-eject'
+
+VOLUME_OFF = 'audio-volume-muted'
+VOLUME_MIN = 'audio-volume-low'
+VOLUME_MED = 'audio-volume-medium'
+VOLUME_MAX = 'audio-volume-high'
+
+_ICONS = [QL_ICON, EF_ICON, VOLUME_OFF, VOLUME_MIN, VOLUME_MED, VOLUME_MAX,
+          IPOD, STORAGE, EJECT]
 
 def init():
     factory = gtk.IconFactory()
@@ -35,7 +43,6 @@ def init():
         icon_filename = os.path.join(const.BASEDIR, fn + ".png")
         pb = gtk.gdk.pixbuf_new_from_file(icon_filename)
         factory.add(fn, gtk.IconSet(pb))
-    factory.add_default()
 
     gtk.stock_add([
         (EDIT_TAGS, _("Edit _Tags"), 0, 0, ""),
@@ -43,32 +50,36 @@ def init():
         (PREVIEW, _("_Preview"), 0, 0, ""),
         (ENQUEUE, _("Add to _Queue"), 0, 0, ""),
         (PLAYLISTS, _("_Add to Playlist"), 0, 0, ""),
+        (DEVICES, _("_Copy to Device"), 0, 0, ""),
+        (EJECT, _("_Eject"), 0, 0, ""),
+        (RENAME, _("_Rename"), 0, 0, ""),
         ])
 
-    icons = gtk.IconFactory()
     lookup = gtk.icon_factory_lookup_default
-    icons.add(EDIT_TAGS, lookup(gtk.STOCK_PROPERTIES))
-    icons.add(PLUGINS, lookup(gtk.STOCK_EXECUTE))
-    icons.add(PREVIEW, lookup(gtk.STOCK_CONVERT))
-    icons.add(ENQUEUE, lookup(gtk.STOCK_ADD))
-    icons.add(PLAYLISTS, lookup(gtk.STOCK_ADD))
+    factory.add(EDIT_TAGS, lookup(gtk.STOCK_PROPERTIES))
+    factory.add(PLUGINS, lookup(gtk.STOCK_EXECUTE))
+    factory.add(PREVIEW, lookup(gtk.STOCK_CONVERT))
+    factory.add(ENQUEUE, lookup(gtk.STOCK_ADD))
+    factory.add(PLAYLISTS, lookup(gtk.STOCK_ADD))
+    factory.add(DEVICES, lookup(gtk.STOCK_COPY))
+    factory.add(RENAME, lookup(gtk.STOCK_EDIT))
 
     # Introduced in GTK 2.8
     try: gtk.STOCK_INFO
     except AttributeError:
         gtk.STOCK_INFO = 'gtk-info'
         if not gtk.stock_lookup(gtk.STOCK_INFO):
-            icons.add(gtk.STOCK_INFO, lookup(gtk.STOCK_DIALOG_INFO))
+            factory.add(gtk.STOCK_INFO, lookup(gtk.STOCK_DIALOG_INFO))
             gtk.stock_add([(gtk.STOCK_INFO, _("_Information"), 0, 0, "")])
 
-    icons.add(REMOVE, lookup(gtk.STOCK_REMOVE))
+    factory.add(REMOVE, lookup(gtk.STOCK_REMOVE))
     # Translators: Only translate this if it conflicts with "Delete",
     # as is the case in e.g. Finnish. It should be disambiguated as
     # "Remove from Library" (as opposed to, from playlist, from disk, etc.)
     # Don't literally translate "ql-remove". It needs an access key, so
     # a sample translation would be "_Remove from Library".
     if _("ql-remove") == "ql-remove":
-        gtk.stock_add([(REMOVE,)+gtk.stock_lookup(gtk.STOCK_REMOVE)[1:]])
+        gtk.stock_add([(REMOVE,) + gtk.stock_lookup(gtk.STOCK_REMOVE)[1:]])
     else:
         old = gtk.stock_lookup(gtk.STOCK_REMOVE)
         gtk.stock_add([(REMOVE, _("ql-remove"), 0, 0, "")])
@@ -89,9 +100,9 @@ def init():
         # Translators: Only translate this if GTK does so incorrectly or not
         # at all. Don't literally translate media/next/previous/play/pause.
         # This string needs an access key.
-        (gtk.STOCK_MEDIA_PAUSE, _('gtk-media-pause'))
+        (gtk.STOCK_MEDIA_PAUSE, _('gtk-media-pause')),
         ]:
         if key != name: # translated, so re-register with a good name
             gtk.stock_add([(key, name) + gtk.stock_lookup(key)[2:]])
 
-    icons.add_default()
+    factory.add_default()
