@@ -4,12 +4,12 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: __init__.py 3793 2006-08-16 06:25:50Z piman $
+# $Id: __init__.py 3943 2006-11-12 12:40:50Z luks $
 
 import gettext
 import locale
 import os
-import sre
+import re
 import sys
 
 from const import FSCODING as fscoding, ENCODING
@@ -23,10 +23,16 @@ def gettext_install():
     except IOError:
         t = GlibTranslations()
 
-    t.install()
+    t.install(unicode=True)
 
 def python_init():
-    sre.escape = re_esc
+    re.escape = re_esc
+    # Python 2.4 has sre.Scanner but not re.Scanner. Python 2.5 has
+    # deprecated sre and moved Scanner to re.
+    try: re.Scanner
+    except AttributeError:
+        from sre import Scanner
+        re.Scanner = Scanner
 
 def re_esc(str, BAD="/.^$*+?{,\\[]|()<>#=!:"):
     needs_escape = lambda c: (c in BAD and "\\" + c) or c
@@ -42,6 +48,17 @@ def gtk_init():
             def set_search_equal_func(self, func, *args): pass
         gtk.TreeView = TVProxy
 
+def strip_win32_incompat(string, BAD = '\:*?;"<>|'):
+    """Strip Win32-incompatible characters.
+
+    This only works correctly on Unicode strings.
+    """
+    new = u"".join(map(lambda s: (s in BAD and "_") or s, string))
+    parts = new.split(os.sep)
+    def fix_end(string):
+        return re.sub(r'[\. ]$', "_", string)
+    return unicode(os.sep).join(map(fix_end, parts))
+
 def listdir(path, hidden=False):
     """List files in a directory, sorted, fully-qualified.
 
@@ -237,7 +254,7 @@ def unescape(str):
     """Unescape a string in a manner suitable for XML/Pango."""
     return str.replace("&lt;", "<").replace("&gt;", ">").replace("&amp;", "&")
 
-def parse_time(timestr, err=(ValueError, sre.error)):
+def parse_time(timestr, err=(ValueError, re.error)):
     """Parse a time string in hh:mm:ss, mm:ss, or ss format."""
     if timestr[0:1] == "-":
         m = -1
@@ -246,7 +263,7 @@ def parse_time(timestr, err=(ValueError, sre.error)):
 
     try:
         return m * reduce(lambda s, a: s * 60 + int(a),
-                          sre.split(r":|\.", timestr), 0)
+                          re.split(r":|\.", timestr), 0)
     except err: return 0
 
 RATING_PRECISION = 0.25
@@ -362,7 +379,7 @@ def split_value(s, splitters=["/", "&", ","]):
     if not splitters: return [s.strip()]
     values = s.split("\n")
     for spl in splitters:
-        spl = sre.compile(r"\b\s*%s\s*\b" % sre.escape(spl), sre.UNICODE)
+        spl = re.compile(r"\b\s*%s\s*\b" % re.escape(spl), re.UNICODE)
         new_values = []
         for v in values:
             new_values.extend([st.strip() for st in spl.split(v)])
